/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.code.generator.wrapping;

import java.awt.event.ActionEvent;
import java.util.logging.Level;

import javax.swing.AbstractAction;

import edu.stanford.smi.protege.model.KnowledgeBase;
import edu.stanford.smi.protege.ui.ProjectManager;
import edu.stanford.smi.protege.ui.ProjectView;
import edu.stanford.smi.protege.util.Log;
import edu.stanford.smi.protege.util.ModalDialog;


public class JavaCodeGeneratorAction extends AbstractAction {

	public static final String JAVA_CODE_GEN_ACTION_NAME = "Generate Java Code...";

	private KnowledgeBase kb;

	public JavaCodeGeneratorAction(KnowledgeBase kb) {
		this.kb = kb;
	}

    public void actionPerformed(ActionEvent arg0) {
        EditableJavaCodeGeneratorOptions options = new ProjectBasedJavaCodeGeneratorOptions();
        JavaCodeGeneratorPanel panel = new JavaCodeGeneratorPanel(kb, options);

        ProjectView view = ProjectManager.getProjectManager().getCurrentProjectView();

        if (ModalDialog.showDialog(view , panel,
                getName(), ModalDialog.MODE_OK_CANCEL) == ModalDialog.OPTION_OK) {
            panel.ok();
            JavaCodeGenerator creator = new JavaCodeGenerator(kb, options);

            try {
                creator.createAll();
                ModalDialog.showMessageDialog(view, "Java code generated successfully in directory:\n" + options.getOutputFolder());
            }
            catch (Exception ex) {
                Log.getLogger().log(Level.SEVERE, "Exception caught", ex);
                ModalDialog.showMessageDialog(view, "Could not create Java code:\n" + ex.getMessage(), ModalDialog.MODE_CLOSE);
            }
        }
    }

    public String getName() {
        return JAVA_CODE_GEN_ACTION_NAME;
    }

}
