/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.server.update;

import java.io.Serializable;
import java.util.List;

import edu.stanford.smi.protege.model.Frame;
import edu.stanford.smi.protege.model.KnowledgeBase;
import edu.stanford.smi.protege.model.Localizable;
import edu.stanford.smi.protege.model.framestore.Sft;
import edu.stanford.smi.protege.server.RemoteSession;
import edu.stanford.smi.protege.util.LocalizeUtils;
import edu.stanford.smi.protege.util.transaction.cache.serialize.CacheModify;
import edu.stanford.smi.protege.util.transaction.cache.serialize.CacheRead;
import edu.stanford.smi.protege.util.transaction.cache.serialize.SerializedCacheUpdate;

public class ValueUpdate implements Serializable, Localizable{
    private static final long serialVersionUID = -7753881900765528485L;
    
	
    private Frame frame;
	private SerializedCacheUpdate<RemoteSession, Sft, List> update;
	

	public ValueUpdate(Frame frame,
					   SerializedCacheUpdate<RemoteSession, Sft, List> update) {
		this.frame = frame;
		this.update = update;
	}
	
	public Frame getFrame() {
		return frame;
	}
	
	public SerializedCacheUpdate<RemoteSession, Sft, List> getUpdate() {
		return update;
	}


	public void localize(KnowledgeBase kb) {
	    LocalizeUtils.localize(frame, kb);
	    if (update instanceof CacheRead) {
	        CacheRead<RemoteSession, Sft, List> read = (CacheRead<RemoteSession, Sft, List>) update;
	        read.getVar().localize(kb);
	        LocalizeUtils.localize(read.getValue().getResult(), kb);
	    }
	    else if (update instanceof CacheModify) {
	        CacheModify<RemoteSession, Sft, List> modify = (CacheModify<RemoteSession, Sft, List>) update;
	        modify.getVar().localize(kb);
	        LocalizeUtils.localize(modify.getNewValue().getResult(), kb);
	    }
	}
	
	public String toString() {
		StringBuffer sb = new StringBuffer("{");
		sb.append(update);
		sb.append(" applied to ");
		if (frame != null) {
		    sb.append(frame.getFrameID().getName());
		    sb.append(" cache}");
		}
		else {
		    sb.append("all frame caches");
		}
		return sb.toString();
	}
}
