/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.util;

import java.util.logging.Level;
import java.util.logging.Logger;

import edu.stanford.smi.protege.exception.ProtegeException;
import edu.stanford.smi.protege.server.RemoteSession;
import edu.stanford.smi.protege.server.Server;
import edu.stanford.smi.protege.server.ServerProject;
import edu.stanford.smi.protege.server.framestore.ServerFrameStore;
import edu.stanford.smi.protege.server.metaproject.Operation;
import edu.stanford.smi.protege.server.metaproject.Policy;
import edu.stanford.smi.protege.server.metaproject.ProjectInstance;
import edu.stanford.smi.protege.server.metaproject.User;

public abstract class RemoteJob {
    private Logger log = Log.getLogger(RemoteJob.class);
    
    /**
     * This class is overridden by the sub class and defines 
     * the fuunctionality of this job.  The intention is that the
     * sub-class will define this method and callers will use the 
     * execute() method.
     * 
     * @return 
     * @throws ProtegeException
     */
    public abstract Object run() throws ProtegeException;

    public abstract void fixLoader();
    
    public boolean serverSideCheckOperationAllowed(Operation op, ProjectInstance projectInstance) {
        Policy policy = Server.getPolicy();
        String userName = ServerFrameStore.getCurrentSession().getUserName();
        User user = policy.getUserByName(userName);
        boolean allowed = policy.isOperationAuthorized(user, op, projectInstance);
        if (!allowed) {
            log.warning("User " + userName + " attempted the operation " + op);
            log.warning("Permission denied");
        }
        return allowed;
    }
}
