/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.util;

import java.io.Serializable;
import java.rmi.RemoteException;
import java.util.logging.Level;
import java.util.logging.Logger;

import edu.stanford.smi.protege.exception.ProtegeException;
import edu.stanford.smi.protege.model.DefaultKnowledgeBase;
import edu.stanford.smi.protege.model.KnowledgeBase;
import edu.stanford.smi.protege.model.framestore.FrameStore;
import edu.stanford.smi.protege.server.RemoteServer;
import edu.stanford.smi.protege.server.RemoteSession;
import edu.stanford.smi.protege.server.framestore.RemoteClientFrameStore;

public abstract class ServerJob extends RemoteJob implements Serializable {
    private static final long serialVersionUID = -7633748858975967471L;
    private static transient Logger log = Log.getLogger(ServerJob.class);
    
    private RemoteServer server;
    private RemoteSession session;

    public ServerJob(RemoteServer server, RemoteSession session) {
        this.server = server;
        this.session = session;
    }
    
    public ServerJob(KnowledgeBase kb) {
        DefaultKnowledgeBase dkb = (DefaultKnowledgeBase) kb;
        FrameStore terminalFrameStore = dkb.getTerminalFrameStore();
        if (terminalFrameStore instanceof RemoteClientFrameStore) {
          RemoteClientFrameStore clientFrameStore = (RemoteClientFrameStore) terminalFrameStore;
          
          server = clientFrameStore.getRemoteServer();
          session = clientFrameStore.getSession();
        }
    }
    
    public void fixLoader() {
  	  ClassLoader currentLoader = Thread.currentThread().getContextClassLoader();
  	  ClassLoader correctLoader = getClass().getClassLoader();
  	  if (currentLoader != correctLoader) {
  		  if (log.isLoggable(Level.FINEST)) {
  			  Log.getLogger().finest("Changing loader from " + currentLoader + " to " + correctLoader);
  		  }
  		  Thread.currentThread().setContextClassLoader(correctLoader);
  	  }
    }
    
    public RemoteSession getSession() {
        return session;
    }
    
    public Object execute() throws ProtegeException {
        try {
            return server.executeServerJob(this, session);
        }
        catch (RemoteException re) {
            throw new ProtegeException(re);
        }
    }
    
}
